aboutsummaryrefslogtreecommitdiffstats
path: root/doc/yat2m.c
diff options
context:
space:
mode:
Diffstat (limited to 'doc/yat2m.c')
-rw-r--r--doc/yat2m.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/doc/yat2m.c b/doc/yat2m.c
index 9411e3419..587428fa0 100644
--- a/doc/yat2m.c
+++ b/doc/yat2m.c
@@ -42,7 +42,7 @@
the next input line if that line begins with @section, @subsection or
@chapheading.
- To insert verbatim troff markup, the follwing texinfo code may be
+ To insert verbatim troff markup, the following texinfo code may be
used:
@ifset manverb
@@ -842,7 +842,7 @@ parse_file (const char *fname, FILE *fp, char **section_name, int in_pause)
{
char *line;
int lnr = 0;
/* Fixme: The follwing state variables don't carry over to include
files. */
int in_verbatim = 0;
int skip_to_end = 0; /* Used to skip over menu entries. */
@@ -842,7 +842,7 @@ parse_file (const char *fname, FILE *fp, char **section_name, int in_pause)
char *line;
int lnr = 0;
- /* Fixme: The follwing state variables don't carry over to include
+ /* Fixme: The following state variables don't carry over to include
files. */
int in_verbatim = 0;